@@ -1,5 +1,5 @@
 package Glitch;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 use 5.006; use strict; use warnings;
 use Data::Dumper; use feature qw/state/;
 state %GLITCHES;
@@ -92,7 +92,7 @@ Glitch - Exception Handling.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
@@ -131,8 +131,8 @@ Version 0.03
 			do { ... } or glitch('two', fileName => 'abc');
 		};
 		if ($@) {
-			do { ... } if $@->name == 'one';
-			do { ... } if $@->name == 'two';
+			do { ... } if $@->name eq 'one';
+			do { ... } if $@->name eq 'two';
 		}
 	}
 
@@ -166,8 +166,8 @@ Version 0.03
 			do { ... } or glitch('two', fileName => 'abc');
 		};
 		if ($@) {
-			if ($@->name == 'one') { ... }
-			elsif ($@->name == 'two') { ... }
+			if ($@->name eq 'one') { ... }
+			elsif ($@->name eq 'two') { ... }
 		}
 	}
 
